@@ -1,6 +1,5 @@
 -- This template expects CPP definitions for:
 --     PLATFORM_NAME = Posix | Windows
---     IS_WINDOWS    = False | True
 
 -- | This library provides a well-typed representation of paths in a filesystem
 -- directory tree.
@@ -483,8 +482,8 @@ splitExtension (Path fpath) =
             xtn  = (takeWhile notSep . dropWhile isSep) rstr
         in (reverse name, reverse xtn ++ trailingSeps)
     normalizeDrive
-        | IS_WINDOWS = normalizeTrailingSeps
-        | otherwise  = id
+      | isWindows = normalizeTrailingSeps
+      | otherwise = id
 
     (drv, pth)     = FilePath.splitDrive fpath
     (dir, file)    = splitLast FilePath.isPathSeparator pth
@@ -818,6 +817,16 @@ normalizeDir =
           | p == relRootFP = ""
           | otherwise = p
 
+-- | Normalizes seps only at the beginning of a path.
+normalizeLeadingSeps :: FilePath -> FilePath
+normalizeLeadingSeps path = normLeadingSep ++ rest
+  where (leadingSeps, rest) = span FilePath.isPathSeparator path
+        normLeadingSep = replicate (min 1 (length leadingSeps)) FilePath.pathSeparator
+
+-- | Normalizes seps only at the end of a path.
+normalizeTrailingSeps :: FilePath -> FilePath
+normalizeTrailingSeps = reverse . normalizeLeadingSeps . reverse
+
 -- | Replaces consecutive path seps with single sep and replaces alt sep with standard sep.
 normalizeAllSeps :: FilePath -> FilePath
 normalizeAllSeps = foldr normSeps []
@@ -834,21 +843,11 @@ normalizeWindowsSeps path = normLeadingSeps ++ normalizeAllSeps rest
   where (leadingSeps, rest) = span FilePath.isPathSeparator path
         normLeadingSeps = replicate (min 2 (length leadingSeps)) FilePath.pathSeparator
 
--- | Normalizes seps only at the beginning of a path.
-normalizeLeadingSeps :: FilePath -> FilePath
-normalizeLeadingSeps path = normLeadingSep ++ rest
-  where (leadingSeps, rest) = span FilePath.isPathSeparator path
-        normLeadingSep = replicate (min 1 (length leadingSeps)) FilePath.pathSeparator
-
--- | Normalizes seps only at the end of a path.
-normalizeTrailingSeps :: FilePath -> FilePath
-normalizeTrailingSeps = reverse . normalizeLeadingSeps . reverse
-
 -- | Applies platform-specific sep normalization following @FilePath.normalise@.
 normalizeFilePath :: FilePath -> FilePath
 normalizeFilePath
-  | IS_WINDOWS = normalizeWindowsSeps . FilePath.normalise
-  | otherwise  = normalizeLeadingSeps . FilePath.normalise
+  | isWindows = normalizeWindowsSeps . FilePath.normalise
+  | otherwise = normalizeLeadingSeps . FilePath.normalise
 
 -- | Path of some type.  @t@ represents the type, whether file or
 -- directory.  Pattern match to find whether the path is absolute or
